

ParticleDefinitions[GaugeES] = {
    {q1,     {Description -> "Quark triplet 1",
	      LaTeX -> "Q_L^1",
              OutputName -> "q1"}},
    {q2,     {Description -> "Quark triplet 2",
	      LaTeX -> "Q_L^2",
              OutputName -> "q2"}},
    {q3,     {Description -> "Quark triplet 3",
	      LaTeX -> "Q_L^3",
              OutputName -> "q1"}},
    {phi1,   {Description -> "Phi 1",
	      LaTeX -> "\\phi_1",
              OutputName -> "phi1" }},
    {phi2,   {Description -> "Phi 2",
	      LaTeX -> "\\phi_2",
              OutputName -> "phi2" }},
    {phi3,   {Description -> "Phi 3",
	      LaTeX -> "\\phi_3",
              OutputName -> "phi3" }},
    {phiX,   {Description -> "Phi X",
	      LaTeX -> "\\phi_X",
              OutputName -> "phiX" }},

    {dR,     {LaTeX -> "d_R" }},
    {eR,     {LaTeX -> "e_R" }},
    {lep,    {LaTeX -> "l" }},
    {uR,     {LaTeX -> "u_R" }},
    {q,      {LaTeX -> "q" }},
    {eL,     {LaTeX -> "e_L" }},
    {dL,     {LaTeX -> "d_L" }},
    {uL,     {LaTeX -> "u_L" }},
    {vL,     {LaTeX -> "\\nu_L" }},
    {NL,     {LaTeX -> "N^c" }},
    {sR,     {LaTeX -> "s" }},
    {sL,     {LaTeX -> "s_L" }},
    {bL,     {LaTeX -> "b_L" }},
    {dpL,    {LaTeX -> "d_L^\\prime" }},
    {spL,    {LaTeX -> "s_L^\\prime" }},
    {cL,     {LaTeX -> "c_L" }},
    {tL,     {LaTeX -> "t_L" }},
    {tpL,    {LaTeX -> "t_L^\\prime" }},

    {H0,     {   PDG -> {0},
                 Width -> 0, 
                 Mass -> Automatic,
                 FeynArtsNr -> 1,
                 LaTeX -> "H^0",
                 OutputName -> "H0" }},                           
    {Hp,     {   PDG -> {0},
                 Width -> 0, 
                 Mass -> Automatic,
                 FeynArtsNr -> 2,
                 LaTeX -> "H^+",
                 OutputName -> "Hp" }}, 
                 
    {VB,   { Description -> "B-Boson"}},                                  
    {VG,   { Description -> "Gluon"}},          
    {VWB,  { Description -> "W-Bosons"}},          
    {gB,   { Description -> "B-Boson Ghost"}},                  
    {gG,   { Description -> "Gluon Ghost" }},          
    {gWB,  { Description -> "W-Boson Ghost"}}
      
};
      
    
ParticleDefinitions[EWSB] = {
      {VP,   { Description -> "Photon"}}, 
      {VZ,   { Description -> "Z-Boson",
	       Goldstone -> Ah[{1}] }}, 
      {VZp,  { Description -> "Z-Boson prime",
	       PDG -> {2023},
	       PDG.IX ->{222000001},
	       Width -> External, 
	       Mass -> LesHouches,
	       FeynArtsNr -> 2,
	       ElectricCharge -> 0,
	       Goldstone -> Ah[{2}],
	       LaTeX -> "Z^\\prime",
	       OutputName -> "Zp" }},
      {VX, {  Description -> "X-Boson",
	      PDG -> {3023},
	      PDG.IX ->{322000001},
	      Width -> External, 
	      Mass -> LesHouches,
	      FeynArtsNr -> 2,
	      ElectricCharge -> 0,
	      Goldstone -> Ahd[{1}],
	      LaTeX -> "X",
	      OutputName -> "X" }},
      {VY, {  Description -> "Y-Boson",
	      PDG -> {4023},
	      PDG.IX ->{422000001},
	      Width -> External, 
	      Mass -> LesHouches,
	      FeynArtsNr -> 2,
	      ElectricCharge -> 0,
	      Goldstone -> hhd[{1}],
	      LaTeX -> "Y",
	      OutputName -> "Y" }},

      {VG,   { Description -> "Gluon" }},          
      {VWp,  { Description -> "W+ - Boson",
	       Goldstone -> Hpm[{1}] }}, 
      {VWpp, { Description -> "W+ - Boson prime",
	       PDG -> {224},
	       PDG.IX ->{220000601},
	       Width -> External, 
	       Mass -> LesHouches, 
	       FeynArtsNr -> 3,
	       ElectricCharge -> 1,
	       Goldstone -> Hpmd[{1}],
	       LaTeX -> {"{W^\\prime}^+","{W^\\prime}^-"},
	       OutputName -> {"Wpp","Wmp"} }},
        
      {gP,   { Description -> "Photon Ghost"}},                               
      {gWp,  { Description -> "Positive W+ - Boson Ghost"}}, 
      {gWpC, { Description -> "Negative W+ - Boson Ghost" }}, 
      {gZ,   { Description -> "Z-Boson Ghost" }},
      {gG,   { Description -> "Gluon Ghost" }},  

      {gWppC, { Description -> "Negative W-Boson prime Ghost",
		PDG -> 0,
		PDG.IX -> 0,
		Mass -> Mass[VWpm],
		FeynArtsNr -> 3,
		ElectricCharge -> -1,
		LaTeX -> "{\\eta^\\prime}-",
		OutputName -> "gWpm" }},        
       {gWpp, { Description -> "Positive W-Boson prime Ghost", 
		PDG -> 0,
		PDG.IX -> 0,
		Mass -> Mass[VWpm],
		FeynArtsNr -> 4,
		ElectricCharge -> 1,
		LaTeX -> "{\\eta^\\prime}+",
		OutputName -> "gWpp" }},
      {gZp,   { Description -> "Z-boson prime Ghost",
		PDG -> 0,
		PDG.IX -> 0,
		Width -> 0, 
		Mass -> 0,
		FeynArtsNr -> 1,
		ElectricCharge -> 0,
		LaTeX -> "\\eta^{Z^\\prime}",
		OutputName -> "gZp" }},
      {gX,    { Description -> "X-boson Ghost",
		PDG -> 0,
		PDG.IX -> 0,
		Width -> 0, 
		Mass -> 0,
		FeynArtsNr -> 1,
		ElectricCharge -> 0,
		LaTeX -> "\\eta^X",
		OutputName -> "gX" }},
      {gY,    { Description -> "Y-boson Ghost",
		PDG -> 0,
		PDG.IX -> 0,
		Width -> 0, 
		Mass -> 0,
		FeynArtsNr -> 1,
		ElectricCharge -> 0,
		LaTeX -> "\\eta^Y",
		OutputName -> "gY" }},

      {hh,  {  Description -> "Higgs",
	       PDG -> {25, 35, 1035},
	       PDG.IX -> {101000001,101000002,101000003}}}, 

      {hhd, {  PDG -> {0, 2035},
	       PDG.IX -> {0,101000004},
               LaTeX -> "h^\\prime",
               ElectricCharge -> 0,
               OutputName -> "h2"}}, 

      {rhoX, {  PDG -> {3035},
	        PDG.IX -> {101000005},
                LaTeX -> "\\rho_X",
                ElectricCharge -> 0,
		OutputName -> "rhx"}}, 

      {rhoXt,{  PDG -> {4035},
		PDG.IX -> {101000006},
                LaTeX -> "\\tilde \\rho_X",
                ElectricCharge -> 0,
		OutputName -> "rhxt"}}, 
                 
      {Ah,  {  Description -> "Pseudo-Scalar Higgs",
	       PDG -> {0, 0, 36},
	       PDG.IX -> {0, 0, 102000001}}},

      {Ahd, { PDG -> {0, 1036},
	      PDG.IX -> {0, 102000002},
              LaTeX -> "A^{0 \\prime}",
              ElectricCharge -> 0,
              OutputName -> "Ahd"}},

      {sigmaX, { PDG -> {2036},
	         PDG.IX -> {102000003},
                 LaTeX -> "\\sigma_X",
                 ElectricCharge -> 0,
		 OutputName -> "sgx"}},

      {sigmaXt, { PDG -> {3036},
	          PDG.IX -> {102000004},
		  LaTeX -> "\\tilde \\sigma_X",
		  ElectricCharge -> 0,
		  OutputName -> "sgxt"}},
      
      {Hpm,  { Description -> "Charged Higgs", 
	      PDG -> {0,-37},
	      PDG.IX -> {0,-100000601},
	      Width -> External, 
	      Mass -> LesHouches,
	      ElectricCharge -> -1,
	      LaTeX -> "H^\\pm",
	      OutputName -> "Hpm"}},

      {Hpmd,  { PDG -> {0,-39},
	      PDG.IX -> {0,-200000601},
	      Width -> External, 
	      Mass -> LesHouches,
	      ElectricCharge -> -1,
	      LaTeX -> "H^{\\pm \\prime}",
	      OutputName -> "Hpmd"}},

      {phiXp, { PDG -> {-41},
	      PDG.IX -> {-300000601},
	      Width -> External, 
	      Mass -> LesHouches,
	      ElectricCharge -> 1,
	      LaTeX -> "\\phi_X^+",
	      OutputName -> "phXp"}},
                 
      {Fd, {   Description -> "Down-Quarks",
	       PDG -> {1,3,5,1001,1003},
	       PDG.IX->{-110890201,-110890202,-110890203,-110890204,110890205},
	       Mass -> {0.0035, 0.104, 4.20, LesHouches, LesHouches},
	       Width -> {0, 0, 0, 0, 0},
	       FeynArtsNr -> 4,
	       LaTeX -> "d",
	       ElectricCharge -> -1/3,
	       OutputName -> "d" }}, 
  
     {Fu, {   Description -> "Up-Quarks",
	      PDG -> {2,4,6,1006},
	      PDG.IX->{110100401,110100402,110100403,110100404},
	      Mass -> {0.0015, 1.27, 171.2, LesHouches},
	      Width -> {0, 0, 1.51, 0},
	      FeynArtsNr -> 3,
	      LaTeX -> "u",
	      ElectricCharge -> 2/3,
	      OutputName -> "u" }},

     {Fe, {   Description -> "Leptons" }},
     {Fv, {   Description -> "Neutrinos",
	      PDG -> {12,14,16,1012,1014,1016,2012,2014,2016},
	      PDG.IX ->{-110000001,-110000002,-110000003,-110000004,-110000005,-110000006,-110000007,-110000008,-110000009},
	      Width -> {0,0,0,0,0,0,0,0,0}, 
	      Mass -> {0,0,0,0,0,0,0,0,0},
	      FeynArtsNr -> 1,
	      ElectricCharge -> 0,
	      LaTeX -> "\\nu",
	      OutputName -> "nu" }}
      
  };            
        
        
 WeylFermionAndIndermediate = {
     
    {H,      {   PDG -> {0},
                 Width -> 0, 
                 Mass -> Automatic,
                 LaTeX -> "H",
                 OutputName -> "" }},

    {dR,     {LaTeX -> "d_R" }},
    {eR,     {LaTeX -> "e_R" }},
    {lep,    {LaTeX -> "l" }},
    {uR,     {LaTeX -> "u_R" }},
    {q,      {LaTeX -> "q" }},
    {eL,     {LaTeX -> "e_L" }},
    {dL,     {LaTeX -> "d_L" }},
    {uL,     {LaTeX -> "u_L" }},
    {vL,     {LaTeX -> "\\nu_L" }},
    {NL,     {LaTeX -> "N^c" }},
    {sR,     {LaTeX -> "s" }},
    {sL,     {LaTeX -> "s_L" }},
    {bL,     {LaTeX -> "b_L" }},
    {dpL,    {LaTeX -> "d_L^\\prime" }},
    {spL,    {LaTeX -> "s_L^\\prime" }},
    {cL,     {LaTeX -> "c_L" }},
    {tL,     {LaTeX -> "t_L" }},
    {tpL,    {LaTeX -> "t_L^\\prime" }},
    
    {utR,    {LaTeX -> "T_R" }},
    {dtR,    {LaTeX -> "\\hat{d}_R" }},
    
    {FDR,    {LaTeX -> "D_R" }},
    {FER,    {LaTeX -> "E_R" }},
    {FUR,    {LaTeX -> "U_R" }},
    {FEL,    {LaTeX -> "E_L" }},
    {FDL,    {LaTeX -> "D_L" }},
    {FUL,    {LaTeX -> "U_L" }},
    {FV,     {LaTeX -> "\\nu_M" }},
    
    {rho1, {  Description -> "CP-even state 1",
	      LaTeX -> "\\rho_1",
	      OutputName -> "rho1" }},
    {rho2, {  Description -> "CP-even state 2",
	      LaTeX -> "\\rho_2",
	      OutputName -> "rho2" }},
    {rho3, {  Description -> "CP-even state 3",
	      LaTeX -> "\\rho_3",
	      OutputName -> "rho3" }},
    {rho4, {  Description -> "CP-even state 4",
	      LaTeX -> "\\rho_4",
	      OutputName -> "rho4" }},
    {rho5, {  Description -> "CP-even state 5",
	      LaTeX -> "\\rho_5",
	      OutputName -> "rho5" }},
    {rhoX, {  Description -> "CP-even state 6",
	      LaTeX -> "\\rho_X",
	      OutputName -> "rhoX" }},
    {rhoXt, {  Description -> "CP-even state 7",
	       LaTeX -> "\\rho_X^\\prime",
	       OutputName -> "rhoXt" }},
    
    {sigma1, {  Description -> "CP-odd state 1",
		LaTeX -> "\\sigma_1",
		OutputName -> "sigma1" }},
    {sigma2, {  Description -> "CP-odd state 2",
		LaTeX -> "\\sigma_2",
		OutputName -> "sigma2" }},
    {sigma3, {  Description -> "CP-odd state 3",
		LaTeX -> "\\sigma_3",
		OutputName -> "sigma3" }},
    {sigma4, {  Description -> "CP-odd state 4",
		LaTeX -> "\\sigma_4",
		OutputName -> "sigma4" }},
    {sigma5, {  Description -> "CP-odd state 5",
		LaTeX -> "\\sigma_5",
		OutputName -> "sigma5" }},
    {sigmaX, {  Description -> "CP-odd state 6",
		LaTeX -> "\\sigma_X",
		OutputName -> "sigmaX" }},
    {sigmaXt, {  Description -> "CP-odd state 7",
                 LaTeX -> "\\sigma_X^\\prime",
		 OutputName -> "sigmaXt" }},

    {phi10, {  Description -> "phi10 component",
	       LaTeX -> "\\phi_1",
	       OutputName -> "phi10" }},
    {phi1m, {  Description -> "phi1m component",
	       LaTeX -> "\\phi_1^-",
	       OutputName -> "phi1m" }},
    {phi1mt, {  Description -> "phi1mt component",
		LaTeX -> "S_1^-",
		OutputName -> "phi1mt" }},
    {phi2p, {  Description -> "phi2p component",
	       LaTeX -> "\\phi_2^+",
	       OutputName -> "phi2p" }},
    {phi20, {  Description -> "phi20 component",
	       LaTeX -> "\\phi_2",
	       OutputName -> "phi20" }},
    {phi20t, {  Description -> "phi20t component",
		LaTeX -> "S_2",
		OutputName -> "phi20t" }},
    {phi3p, {  Description -> "phi3p component",
	       LaTeX -> "\\phi_3^+",
	       OutputName -> "phi3p" }},
    {phi30, {  Description -> "phi30 component",
	       LaTeX -> "\\phi_3",
	       OutputName -> "phi30" }},
    {phi30t, {  Description -> "phi30t component",
		LaTeX -> "S_3",
		OutputName -> "phi30t" }},
    {phiXp, {  Description -> "phiXp component",
	       LaTeX -> "\\phi_X^+",
	       OutputName -> "phiXp" }},
    {phiX0, {  Description -> "phiX0 component",
	       LaTeX -> "\\phi_X",
	       OutputName -> "phiX0" }},
    {phiX0t, {  Description -> "phiX0t component",
		LaTeX -> "X",
		OutputName -> "phiX0t" }},

    {q1,    { Description -> "Quark triplet 1",
	      LaTeX -> "Q_L^1",
              OutputName -> "q1"}},
    {q2,    { Description -> "Quark triplet 2",
	      LaTeX -> "Q_L^2",
              OutputName -> "q2"}},
    {q3,    { Description -> "Quark triplet 3",
	      LaTeX -> "Q_L^3",
              OutputName -> "q1"}},
    {phi1,  { Description -> "Phi 1",
	      LaTeX -> "\\phi_1",
              OutputName -> "phi1" }},
    {phi2,  { Description -> "Phi 2",
	      LaTeX -> "\\phi_2",
              OutputName -> "phi2" }},
    {phi3,  { Description -> "Phi 3",
	      LaTeX -> "\\phi_3",
              OutputName -> "phi3" }}

        };       


